@@ -1,6 +1,6 @@
 package MARC::Moose::Formater::UnimarcToMarc21;
 {
-  $MARC::Moose::Formater::UnimarcToMarc21::VERSION = '0.027';
+  $MARC::Moose::Formater::UnimarcToMarc21::VERSION = '0.028';
 }
 # ABSTRACT: Convert biblio record from UNIMARC to MARC21
 use Moose;
@@ -251,58 +251,59 @@ override 'format' => sub {
 
     # 100 => 008
     if ( my $field = $unimarc->field('100') ) {
-        # Date entered on file
-        my $code100 = $field->subfield('a');
-        substr $code008, 0, 6, substr($code100, 2, 6);
+        if ( my $code100 = $field->subfield('a') ) {
+            # Date entered on file
+            substr $code008, 0, 6, substr($code100, 2, 6);
 
-        # Type of publication date
-        my $value = substr($code100, 8, 1);
-        $value = $typeofpub{$value} || ' ';
-        substr $code008, 6, 1, $value;
+            # Type of publication date
+            my $value = substr($code100, 8, 1);
+            $value = $typeofpub{$value} || ' ';
+            substr $code008, 6, 1, $value;
 
-        # Date 1
-        $value = substr($code100, 9, 4);
-        if ( 1 ) { #FIXME Determine if it's a serials
-            # Not serials
-            my $count = 0;
-            for ( split //, $value ) { $count++ if / /; }
-            $value =~ s/ /0/g  if $count <= 3;
-        }
-        else {
-            # A serials
-            $value =~ s/ /u/g;
-        }
-        substr $code008, 7, 4, $value;
+            # Date 1
+            $value = substr($code100, 9, 4);
+            if ( 1 ) { #FIXME Determine if it's a serials
+                # Not serials
+                my $count = 0;
+                for ( split //, $value ) { $count++ if / /; }
+                $value =~ s/ /0/g  if $count <= 3;
+            }
+            else {
+                # A serials
+                $value =~ s/ /u/g;
+            }
+            substr $code008, 7, 4, $value;
 
-        # Date 2
-        $value = substr($code100, 13, 4);
-        if ( 1 ) { #FIXME Determine if it's a serials
-            # Not serials
-            my $count = 0;
-            for ( split //, $value ) { $count++ if / /; }
-            $value =~ s/ /0/g  if $count <= 3;
-        }
-        else {
-            # A serials
-            $value =~ s/ /u/g;
-        }
-        substr $code008, 11, 4, $value;
+            # Date 2
+            $value = substr($code100, 13, 4);
+            if ( 1 ) { #FIXME Determine if it's a serials
+                # Not serials
+                my $count = 0;
+                for ( split //, $value ) { $count++ if / /; }
+                $value =~ s/ /0/g  if $count <= 3;
+            }
+            else {
+                # A serials
+                $value =~ s/ /u/g;
+            }
+            substr $code008, 11, 4, $value;
 
-        # 3 positions for target audience
-        $value = substr($code100, 17, 3);
-        for (my $i=0; $i < 3; $i++) {
-            $value = substr($code100, 17+$i, 1);
-            $value = $target_audience{$value} || ' ';   
-            substr $code008, 17+$i, 1, $value;
-        }
-        
-        # Language of cataloging
-        push @sf040, [ b => substr($code100, 22, 3) ];
+            # 3 positions for target audience
+            $value = substr($code100, 17, 3);
+            for (my $i=0; $i < 3; $i++) {
+                $value = substr($code100, 17+$i, 1);
+                $value = $target_audience{$value} || ' ';   
+                substr $code008, 17+$i, 1, $value;
+            }
+            
+            # Language of cataloging
+            push @sf040, [ b => substr($code100, 22, 3) ];
 
-        # Alphabet of title, converted if serials
-        # FIXME
-        if ( 0 ) {
-            substrr $code008, 33, 1, substr($code100,34,1);
+            # Alphabet of title, converted if serials
+            # FIXME
+            if ( 0 ) {
+                substrr $code008, 33, 1, substr($code100,34,1);
+            }
         }
     }
 
@@ -522,8 +523,9 @@ override 'format' => sub {
                     }
                 }
                 when ( /f/ ) {
+                    print $unimarc->as('Text');
                     if ( $b_index == -1 ) {
-                        $sf[-1]->[1] .= " / ";
+                        $sf[-1]->[1] .= " / " if @sf;
                         push @sf, [ b => $value];
                         $b_index = $#sf;
                     }
@@ -1056,6 +1058,11 @@ override 'format' => sub {
         }
     }
 
+    # 856: copied as it is
+    if ( my @fields = $unimarc->field('856') ) {
+        $record->append(@fields)
+    }
+
     return $record;
 };
 
@@ -1075,7 +1082,7 @@ MARC::Moose::Formater::UnimarcToMarc21 - Convert biblio record from UNIMARC to M
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 SYNOPSYS
 
